/**
 * ************************************************************
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 *
 ************************************************************
 */
/*
 * OfficeUNOClientApp.java
 *
 * Created on 2015.07.03 - 14:40:13
 *
 */
package com.example;

import com.sun.star.beans.PropertyValue;
import com.sun.star.beans.XPropertySet;
import com.sun.star.uno.XComponentContext;
import com.sun.star.comp.helper.Bootstrap;
import com.sun.star.comp.helper.BootstrapException;
import com.sun.star.frame.XComponentLoader;
import com.sun.star.lang.XComponent;
import com.sun.star.lang.XMultiComponentFactory;
import com.sun.star.lang.XMultiServiceFactory;
import com.sun.star.table.BorderLine;
import com.sun.star.table.XCellRange;
import com.sun.star.text.XText;
import com.sun.star.text.XTextCursor;
import com.sun.star.text.XTextDocument;
import com.sun.star.text.XTextTable;
import com.sun.star.uno.UnoRuntime;

/**
 *
 * @author martin
 */
public class OfficeUNOClientApp {

    /**
     * Creates a new instance of OfficeUNOClientApp
     */
    public OfficeUNOClientApp() {
    }

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {

        boolean DEBUG = false;
        XComponentContext xComponentContext = null;
        XMultiComponentFactory xMCF = null;
        Object desktop = null;
        XComponentLoader xComponentLoader = null;
        XComponent xWriterComponent = null;
        XTextDocument xTextDocument = null;
        XMultiServiceFactory docServiceFactory = null; // textcontent creator
        // get the remote office component context
        try {
            xComponentContext = Bootstrap.bootstrap();
            if (xComponentContext == null) {
                System.err.println("ERROR: Could not bootstrap default Office.");
            }
            try {
                xMCF = xComponentContext.getServiceManager();
                desktop = xMCF.createInstanceWithContext("com.sun.star.frame.Desktop", xComponentContext);
                xComponentLoader = (XComponentLoader) UnoRuntime.queryInterface(XComponentLoader.class, desktop);
                PropertyValue[] loadProps = new PropertyValue[0];
                // verkrijg een leeg document
                xWriterComponent = xComponentLoader.loadComponentFromURL("private:factory/swriter", "_blank", 0, loadProps);
                xTextDocument = (XTextDocument) UnoRuntime.queryInterface(XTextDocument.class, xWriterComponent);
                // verkrijg een pointer naar de bij document horende "Service Manager"
                docServiceFactory = (XMultiServiceFactory) UnoRuntime.queryInterface(XMultiServiceFactory.class, xTextDocument);

                XText xText = xTextDocument.getText();
                Object textTable = docServiceFactory.createInstance("com.sun.star.text.TextTable");
                XTextTable xTextTable = (XTextTable) UnoRuntime.queryInterface(XTextTable.class, textTable);

                xTextTable.initialize(4, 4);
                // Getting Doc cursor
                XTextCursor xTextCursor = xText.createTextCursor();
                xTextCursor.collapseToEnd();
                xTextCursor.gotoEnd(false);
                // Insert the table into the document
                xText.insertTextContent(xTextCursor, xTextTable, false);
                // set some id
                XCellRange xCellRange = (XCellRange) UnoRuntime.queryInterface(XCellRange.class, xTextTable);
                BorderLine borderstruct = new BorderLine();
                borderstruct.Color = 0;
                borderstruct.InnerLineWidth = 50;
                borderstruct.LineDistance = 0;
                borderstruct.OuterLineWidth = 0;

                xCellRange = xCellRange.getCellRangeByPosition(1, 1, 2, 2);

                XPropertySet xCellProperties = (XPropertySet) UnoRuntime.queryInterface(XPropertySet.class, xCellRange);

                xCellProperties.setPropertyValue("TopBorder", borderstruct);

                Thread.sleep(1000);

                xCellProperties.setPropertyValue("RightBorder", borderstruct);
                xCellProperties.setPropertyValue("BottomBorder", borderstruct);
                xCellProperties.setPropertyValue("LeftBorder", borderstruct);

            } catch (Exception ex) {
                System.out.println("startOpenOffice:" + ex.getMessage());
            }

        } catch (BootstrapException e) {
            e.printStackTrace();
        } finally {
            //xTextDocument.dispose();
            System.exit(0);
        }
    }

}
